@@ -61,6 +61,8 @@ void show_error( const char * const msg, const int errcode = 0,
                  const bool help = false );
 void show_file_error( const char * const filename, const char * const msg,
                       const int errcode = 0 );
+inline void show_stdout_error( const int errcode = 0 )
+  { show_file_error( "(stdout)", "Write error", errcode ); }
 void internal_error( const char * const msg );
 void show_option_error( const char * const arg, const char * const msg,
                         const char * const option_name );
