@@ -43,8 +43,8 @@ for i in ${compressors}; do
 	$i in || compressor_needed
 	printf "Hello World!\n" > hello || framework_failure
 	$i hello || compressor_needed
-	touch zero || framework_failure
-	$i zero || compressor_needed
+	touch em || framework_failure
+	$i em || compressor_needed
 done
 
 cp "${testdir}"/test.txt in || framework_failure
@@ -55,8 +55,8 @@ cp in -- -in- || framework_failure
 cp in.lz -- -in-.lz || framework_failure
 cp in.lz lz_only.lz || framework_failure
 cat in in in in in in > in6 || framework_failure
-bad0_lz="${testdir}"/zero_bad_crc.lz
-bad0_gz="${testdir}"/zero_bad_crc.gz
+bad0_lz="${testdir}"/em_bad_crc.lz
+bad0_gz="${testdir}"/em_bad_crc.gz
 bad1_lz="${testdir}"/test_bad_crc.lz
 touch empty empty.bz2 empty.gz empty.lz || framework_failure
 fail=0
@@ -75,9 +75,9 @@ for i in ${extensions}; do
 	cmp in out || test_failed $LINENO $i
 	"${ZCAT}" -N in.$i empty.$i > out || test_failed $LINENO $i
 	cmp in out || test_failed $LINENO $i
-	"${ZCAT}" -N zero.$i in.$i > out || test_failed $LINENO $i
+	"${ZCAT}" -N em.$i in.$i > out || test_failed $LINENO $i
 	cmp in out || test_failed $LINENO $i
-	"${ZCAT}" -N in.$i zero.$i > out || test_failed $LINENO $i
+	"${ZCAT}" -N in.$i em.$i > out || test_failed $LINENO $i
 	cmp in out || test_failed $LINENO $i
 	"${ZCAT}" -N --format=un in.$i > out || test_failed $LINENO $i
 	cmp in out || test_failed $LINENO $i
@@ -163,7 +163,7 @@ for i in ${extensions}; do
 	"${ZCMP}" -N -i 1kB:1000 -n 500 in6 in.$i || test_failed $LINENO $i
 	"${ZCMP}" -N -i 1KiB:1024 -n 50 in.$i in6 || test_failed $LINENO $i
 	"${ZCMP}" -N empty empty.$i || test_failed $LINENO $i
-	"${ZCMP}" -N empty zero.$i || test_failed $LINENO $i
+	"${ZCMP}" -N empty em.$i || test_failed $LINENO $i
 done
 
 "${ZCMP}" -N -q in in6
@@ -248,7 +248,7 @@ for i in ${extensions}; do
 	"${ZDIFF}" -N in.$i in --force-format=$i, > /dev/null ||
 		test_failed $LINENO $i
 	"${ZDIFF}" -N empty empty.$i > /dev/null || test_failed $LINENO $i
-	"${ZDIFF}" -N empty zero.$i > /dev/null || test_failed $LINENO $i
+	"${ZDIFF}" -N empty em.$i > /dev/null || test_failed $LINENO $i
 done
 
 "${ZDIFF}" -N in in6 > /dev/null
@@ -329,9 +329,12 @@ for i in ${extensions}; do
 	"${ZGREP}" -N --force-format=$i "GNU" in 2> /dev/null
 	[ $? = 2 ] || test_failed $LINENO $i
 	"${ZGREP}" -N "nx_pattern" empty.$i && test_failed $LINENO $i
-	"${ZGREP}" -N "nx_pattern" zero.$i && test_failed $LINENO $i
+	"${ZGREP}" -N "nx_pattern" em.$i && test_failed $LINENO $i
 done
 
+printf "GNU\n" > patfile || framework_failure
+"${ZGREP}" -N -f patfile in > /dev/null || test_failed $LINENO
+rm -f patfile || framework_failure
 "${ZGREP}" -N "nx_pattern" empty && test_failed $LINENO
 "${ZGREP}" -N pin.tar4 -e "GNU" > /dev/null || test_failed $LINENO
 "${ZGREP}" -N "GNU" < pin.tar4 > /dev/null || test_failed $LINENO
@@ -592,7 +595,7 @@ cp in.gz 'name with spaces.gz' || framework_failure
 "${ZCMP}" -N in 'name with spaces.lz' || test_failed $LINENO
 rm -f 'name with spaces.lz' || framework_failure
 
-cp zero.gz z.gz || framework_failure
+cp em.gz z.gz || framework_failure
 "${ZUPDATE}" -N -0 -q z.gz || test_failed $LINENO
 [ ! -e z.gz ] || test_failed $LINENO
 [ -e z.lz ] || test_failed $LINENO
