@@ -257,12 +257,12 @@ void set_signals()
 
 int main( const int argc, const char * const argv[] )
   {
-  enum { bz2_opt = 256, gz_opt, lz_opt, xz_opt, zst_opt };
   std::vector< const char * > diff_args;	// args to diff, maybe empty
   int format_types[2] = { -1, -1 };		// < 0 means undefined
   program_name = "zdiff";
   invocation_name = ( argc > 0 ) ? argv[0] : program_name;
 
+  enum { opt_bz2 = 256, opt_gz, opt_lz, opt_xz, opt_zst };
   const Arg_parser::Option options[] =
     {
     { 'a', "text",                   Arg_parser::no  },
@@ -289,11 +289,11 @@ int main( const int argc, const char * const argv[] )
     { 'w', "ignore-all-space",       Arg_parser::no  },
     { 'W', "width",                  Arg_parser::yes },
     { 'y', "side-by-side",           Arg_parser::no  },
-    { bz2_opt, "bz2",                Arg_parser::yes },
-    { gz_opt,  "gz",                 Arg_parser::yes },
-    { lz_opt,  "lz",                 Arg_parser::yes },
-    { xz_opt,  "xz",                 Arg_parser::yes },
-    { zst_opt, "zst",                Arg_parser::yes },
+    { opt_bz2, "bz2",                Arg_parser::yes },
+    { opt_gz,  "gz",                 Arg_parser::yes },
+    { opt_lz,  "lz",                 Arg_parser::yes },
+    { opt_xz,  "xz",                 Arg_parser::yes },
+    { opt_zst, "zst",                Arg_parser::yes },
     { 0, 0,                          Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
@@ -336,11 +336,11 @@ int main( const int argc, const char * const argv[] )
       case 'w': diff_args.push_back( "-w" ); break;
       case 'W': diff_args.push_back( "-W" ); diff_args.push_back( arg ); break;
       case 'y': diff_args.push_back( "-y" ); break;
-      case bz2_opt: parse_compressor( sarg, pn, fmt_bz2 ); break;
-      case gz_opt: parse_compressor( sarg, pn, fmt_gz ); break;
-      case lz_opt: parse_compressor( sarg, pn, fmt_lz ); break;
-      case xz_opt: parse_compressor( sarg, pn, fmt_xz ); break;
-      case zst_opt: parse_compressor( sarg, pn, fmt_zst ); break;
+      case opt_bz2: parse_compressor( sarg, pn, fmt_bz2 ); break;
+      case opt_gz: parse_compressor( sarg, pn, fmt_gz ); break;
+      case opt_lz: parse_compressor( sarg, pn, fmt_lz ); break;
+      case opt_xz: parse_compressor( sarg, pn, fmt_xz ); break;
+      case opt_zst: parse_compressor( sarg, pn, fmt_zst ); break;
       default: internal_error( "uncaught option." );
       }
     } // end process options
